import numpy as np
from sklearn.svm import SVC
from sklearn.model_selection import train_test_split
from sklearn.metrics import accuracy_score, classification_report
import matplotlib.pyplot as plt

# サンプルデータ作成
np.random.seed(42)
X = np.random.rand(100, 2) * 10  # 2つの特徴量
y = (X[:, 0] + X[:, 1] > 10).astype(int)  # 2つの特徴量の合計で分類

# データ分割
X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.3, random_state=42)

# モデル構築
model = SVC(kernel="linear", random_state=42)
model.fit(X_train, y_train)

# 予測と評価
y_pred = model.predict(X_test)
print("分類精度:", accuracy_score(y_test, y_pred))
print("分類レポート:\n", classification_report(y_test, y_pred))

# 境界線のプロット
plt.scatter(X_train[:, 0], X_train[:, 1], c=y_train, cmap="coolwarm", edgecolors="k", label="Train Data")
plt.title("SVM 境界線")
plt.xlabel("Feature 1")
plt.ylabel("Feature 2")
plt.show()
