import numpy as np
import pandas as pd
from sklearn.model_selection import train_test_split
from sklearn.ensemble import RandomForestClassifier
from sklearn.metrics import accuracy_score, classification_report
import matplotlib.pyplot as plt

# 1. サンプルデータ作成（架空のゲームプレイヤーデータ）
np.random.seed(42)
num_players = 100
game_data = {
    "HoursPlayed": np.random.randint(1, 20, num_players),  # 1〜20時間プレイ
    "Achievements": np.random.randint(0, 50, num_players),  # 実績数
    "Score": np.random.randint(100, 1000, num_players),  # 総スコア
    "WinRate": np.random.uniform(0, 1, num_players),  # 勝率
    "IsPro": (np.random.rand(num_players) > 0.7).astype(int)  # プロゲーマーかどうか（1: プロ, 0: 非プロ）
}

# データをDataFrameに格納
df = pd.DataFrame(game_data)

# 2. データ分割
X = df[["HoursPlayed", "Achievements", "Score", "WinRate"]]
y = df["IsPro"]
X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.3, random_state=42)

# 3. ランダムフォレストモデル構築
model = RandomForestClassifier(n_estimators=50, max_depth=5, random_state=42)
model.fit(X_train, y_train)

# 4. モデル評価
y_pred = model.predict(X_test)
print("=== モデル評価 ===")
print(f"分類精度: {accuracy_score(y_test, y_pred):.2f}")
print("分類レポート:\n", classification_report(y_test, y_pred))

# 5. 特徴量の重要度を可視化
feature_importances = model.feature_importances_
features = X.columns
plt.bar(features, feature_importances, color="blue", edgecolor="black", alpha=0.7)
plt.title("特徴量の重要度")
plt.xlabel("特徴量")
plt.ylabel("重要度")
plt.show()

# 6. プロゲーマーかどうかを予測
sample_player = [[15, 30, 750, 0.8]]  # 新規プレイヤーのデータ
prediction = model.predict(sample_player)
print(f"新規プレイヤーはプロゲーマーか？: {'プロ' if prediction[0] == 1 else '非プロ'}")
