import numpy as np
import pandas as pd
from sklearn.model_selection import train_test_split
from sklearn.ensemble import RandomForestClassifier
from sklearn.metrics import accuracy_score, classification_report
import matplotlib.pyplot as plt

# サンプルデータ作成（架空の顧客データ）
np.random.seed(42)
num_customers = 200
customer_data = {
    "MonthlySpend": np.random.uniform(50, 500, num_customers),  # 月間支出額
    "TenureMonths": np.random.randint(1, 36, num_customers),  # 契約期間（月）
    "SupportCalls": np.random.randint(0, 10, num_customers),  # サポートへの問い合わせ回数
    "ContractType": np.random.choice([0, 1], num_customers),  # 契約タイプ（0: 月額, 1: 年額）
    "Churn": (np.random.rand(num_customers) > 0.75).astype(int)  # 解約フラグ
}

# データをDataFrameに格納
df = pd.DataFrame(customer_data)

# 特徴量とラベルを分割
X = df[["MonthlySpend", "TenureMonths", "SupportCalls", "ContractType"]]
y = df["Churn"]
X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.3, random_state=42)

# ランダムフォレストモデル構築
model = RandomForestClassifier(n_estimators=50, max_depth=5, random_state=42)
model.fit(X_train, y_train)

# モデル評価
y_pred = model.predict(X_test)
print("=== 顧客解約予測モデル ===")
print(f"分類精度: {accuracy_score(y_test, y_pred):.2f}")
print("分類レポート:\n", classification_report(y_test, y_pred))

# 特徴量の重要度を可視化
feature_importances = model.feature_importances_
features = X.columns
plt.bar(features, feature_importances, color="blue", edgecolor="black", alpha=0.7)
plt.title("特徴量の重要度")
plt.xlabel("特徴量")
plt.ylabel("重要度")
plt.show()
