import numpy as np
import pandas as pd
from sklearn.model_selection import train_test_split
from sklearn.ensemble import RandomForestClassifier
from sklearn.metrics import accuracy_score, classification_report
import matplotlib.pyplot as plt

# サンプルデータ作成（架空のローンデータ）
np.random.seed(42)
num_loans = 150
loan_data = {
    "LoanAmount": np.random.uniform(1000, 50000, num_loans),  # 借入金額
    "Income": np.random.uniform(2000, 20000, num_loans),  # 月収
    "CreditScore": np.random.randint(300, 850, num_loans),  # 信用スコア
    "LoanTermMonths": np.random.choice([12, 24, 36, 48, 60], num_loans),  # ローン期間（月）
    "Default": (np.random.rand(num_loans) > 0.8).astype(int)  # 債務不履行フラグ
}

# データをDataFrameに格納
df = pd.DataFrame(loan_data)

# 特徴量とラベルを分割
X = df[["LoanAmount", "Income", "CreditScore", "LoanTermMonths"]]
y = df["Default"]
X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.3, random_state=42)

# ランダムフォレストモデル構築
model = RandomForestClassifier(n_estimators=50, max_depth=5, random_state=42)
model.fit(X_train, y_train)

# モデル評価
y_pred = model.predict(X_test)
print("=== ローン債務不履行予測モデル ===")
print(f"分類精度: {accuracy_score(y_test, y_pred):.2f}")
print("分類レポート:\n", classification_report(y_test, y_pred))

# 特徴量の重要度を可視化
feature_importances = model.feature_importances_
features = X.columns
plt.bar(features, feature_importances, color="green", edgecolor="black", alpha=0.7)
plt.title("特徴量の重要度")
plt.xlabel("特徴量")
plt.ylabel("重要度")
plt.show()
